//
//  Profile+Header.swift
//  Passepartout
//
//  Created by Davide De Rosa on 2/17/22.
//  Copyright (c) 2022 Davide De Rosa. All rights reserved.
//
//  https://github.com/passepartoutvpn
//
//  This file is part of Passepartout.
//
//  Passepartout is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  Passepartout is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with Passepartout.  If not, see <http://www.gnu.org/licenses/>.
//

import Foundation

extension Profile {
    public struct Header: Codable, Identifiable, Hashable {
        public let uuid: UUID
        
        public var name: String
        
        public let providerName: ProviderName?
        
        public let lastUpdate: Date?

        public init(
            uuid: UUID = UUID(),
            name: String = "",
            providerName: ProviderName? = nil,
            lastUpdate: Date? = nil
        ) {
            self.uuid = uuid
            self.name = name
            self.providerName = providerName
            self.lastUpdate = lastUpdate ?? Date()
        }
        
        // MARK: Hashable
        
        public static func ==(lhs: Self, rhs: Self) -> Bool {
            lhs.uuid == rhs.uuid &&
            lhs.name == rhs.name &&
            lhs.providerName == rhs.providerName
        }
        
        public func hash(into hasher: inout Hasher) {
            hasher.combine(uuid)
            hasher.combine(name)
            hasher.combine(providerName)
        }

        // MARK: Identifiable
        
        public var id: UUID {
            uuid
        }
    }
}
